@@ -12,7 +12,7 @@ Usage::
     client: RDSDataServiceClient = boto3.client("rds-data")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -33,7 +33,7 @@ __all__ = ("RDSDataServiceClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -50,7 +50,7 @@ class Exceptions:
 
 class RDSDataServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html)
     """
 
@@ -69,14 +69,14 @@ class RDSDataServiceClient(BaseClient):
         secretArn: str,
         sql: str,
         database: str = None,
-        parameterSets: List[List["SqlParameterTypeDef"]] = None,
+        parameterSets: Sequence[Sequence["SqlParameterTypeDef"]] = None,
         schema: str = None,
         transactionId: str = None
     ) -> BatchExecuteStatementResponseTypeDef:
         """
         Runs a batch SQL statement over an array of data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#batch_execute_statement)
         """
 
@@ -86,7 +86,7 @@ class RDSDataServiceClient(BaseClient):
         """
         Starts a SQL transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#begin_transaction)
         """
 
@@ -94,7 +94,7 @@ class RDSDataServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#can_paginate)
         """
 
@@ -105,7 +105,7 @@ class RDSDataServiceClient(BaseClient):
         Ends a SQL transaction started with the `BeginTransaction` operation and commits
         the changes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#commit_transaction)
         """
 
@@ -121,7 +121,7 @@ class RDSDataServiceClient(BaseClient):
         """
         Runs one or more SQL statements.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_sql)
         """
 
@@ -134,7 +134,7 @@ class RDSDataServiceClient(BaseClient):
         continueAfterTimeout: bool = None,
         database: str = None,
         includeResultMetadata: bool = None,
-        parameters: List["SqlParameterTypeDef"] = None,
+        parameters: Sequence["SqlParameterTypeDef"] = None,
         resultSetOptions: "ResultSetOptionsTypeDef" = None,
         schema: str = None,
         transactionId: str = None
@@ -142,21 +142,21 @@ class RDSDataServiceClient(BaseClient):
         """
         Runs a SQL statement against a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_statement)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#generate_presigned_url)
         """
 
@@ -166,6 +166,6 @@ class RDSDataServiceClient(BaseClient):
         """
         Performs a rollback of a transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#rollback_transaction)
         """
